@@ -4,6 +4,8 @@
 #include <stdio.h>
 #include <orbit/GIOP/giop-types.h>
 
+G_BEGIN_DECLS
+
 #ifdef ORBIT2_INTERNAL_API
 
 typedef enum {
@@ -80,8 +82,10 @@ char                       *giop_recv_buffer_get_opname     (GIOPRecvBuffer *buf
 CORBA_sequence_CORBA_octet *giop_recv_buffer_get_objkey     (GIOPRecvBuffer *buf);
 void                        giop_recv_list_zap              (GIOPConnection *cnx);
 gboolean                    giop_connection_handle_input    (LINCConnection *lcnx);
-
+void                        giop_connection_destroy_frags   (GIOPConnection *cnx);
 
 #endif /* ORBIT2_INTERNAL_API */
 
+G_END_DECLS
+
 #endif
