@@ -5,7 +5,9 @@
 #include <orbit/orb-core/corba-any-type.h>
 #include <orbit/orb-core/orbit-object.h>
 
-#define CORBA_tk_recursive -1
+G_BEGIN_DECLS
+
+#define CORBA_tk_recursive 0xffffffff
 #define CORBA_tk_last (CORBA_tk_abstract_interface + 1)
 
 struct CORBA_TypeCode_struct {
@@ -76,6 +78,8 @@ extern const struct CORBA_TypeCode_struct TC_CORBA_unsigned_long_long_struct;
 
 #ifdef ORBIT2_INTERNAL_API
 
+#include <orbit/GIOP/giop-basics.h>
+
 void        ORBit_encode_CORBA_TypeCode (CORBA_TypeCode  tc,
 					 GIOPSendBuffer *buf);
 gboolean    ORBit_decode_CORBA_TypeCode (CORBA_TypeCode *tc,
@@ -85,4 +89,6 @@ const char *ORBit_tk_to_name            (CORBA_unsigned_long tk);
 
 #endif /*  ORBIT2_INTERNAL_API */
 
+G_END_DECLS
+
 #endif
